@@ -3,22 +3,18 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.
-
-   The author may be contacted at <blp@gnu.org> on the Internet, or
-   write to Ben Pfaff, Stanford University, Computer Science Dept.,
-   353 Serra Mall, Stanford CA 94305, USA. */
+   
+   You should have received a copy of the GNU General Public
+   License along with this program; if not, write to: Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #include <assert.h>
 #include <limits.h>
@@ -1208,8 +1204,7 @@ parse_command_line (int argc, char **argv)
     "This is free software; see the source for copying conditions.  "
     "There is NO\n"
     "WARRANTY; not even for MERCHANTABILITY or FITNESS FOR A "
-    "PARTICULAR PURPOSE.\n\n"
-    "Written by Ben Pfaff <blp@gnu.org>.\n";
+    "PARTICULAR PURPOSE.\n\n";
   
   const char *short_pgm_name = strrchr (argv[0], '/');
   if (short_pgm_name != NULL)
