@@ -1,26 +1,22 @@
 /* Produced by texiweb from libavl.w. */
 
 /* libavl - library for manipulation of binary trees.
-   Copyright (C) 1998-2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004 Free Software
+   Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-   See the GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.
-
-   The author may be contacted at <blp@gnu.org> on the Internet, or
-   write to Ben Pfaff, Stanford University, Computer Science Dept., 353
-   Serra Mall, Stanford CA 94305, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include <assert.h>
@@ -829,8 +825,8 @@ parse_command_line (char **args, struct test_options *options)
           break;
 
         case 'V':
-          fputs ("GNU libavl 2.0.2\n"
-                 "Copyright (C) 1998-2002, 2004 "
+          fputs ("GNU libavl 2.0.3\n"
+                 "Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004 "
                  "Free Software Foundation, Inc.\n"
                  "This program comes with NO WARRANTY, not even for\n"
                  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -1008,7 +1004,7 @@ main (int argc, char *argv[])
   parse_command_line (argv, &opts);
 
   if (opts.verbosity >= 0)
-    fputs ("bst-test for GNU libavl 2.0.2; use --help to get help.\n", stdout);
+    fputs ("bst-test for GNU libavl 2.0.3; use --help to get help.\n", stdout);
 
   if (!opts.seed_given)
     opts.seed = time_seed () % 32768u;
