@@ -3,7 +3,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -12,13 +12,9 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.
-
-   The author may be contacted as blp@gnu.org on the Internet, or
-   write to Ben Pfaff, Stanford University, Computer Science Dept.,
-   353 Serra Mall, Stanford CA 94305, USA. */
+   along with this program; if not, write to: Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+   02110-1301 USA. */
 
 #include <assert.h>
 #include <ctype.h>
@@ -383,7 +379,7 @@ main (int argc, char *argv[])
 	 "\nOptions:\n"
 	 "  -w WIDTH  page width for centering, WIDTH in characters (text)\n"
 	 "            or 1/1000 point (PostScript), default 72 or 612000\n"
-	 "\nReport bugs to Ben Pfaff <blp@gnu.org>.\n", argv[0]);
+	 "\nReport bugs to bug-avl@gnu.org.\n", argv[0]);
 
       return argc == 2 ? EXIT_SUCCESS : EXIT_FAILURE;
     }
@@ -397,8 +393,7 @@ main (int argc, char *argv[])
 	 "not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 	 "You may redistribute copies of texiweb under the terms of the GNU\n"
 	 "General Public License.  For more information about these\n"
-	 "matters, see the file named COPYING.\n"
-	 "Written by Ben Pfaff <blp@gnu.org>.\n");
+	 "matters, see the file named COPYING.\n");
 
       return EXIT_SUCCESS;
     }
